"use client";

import {
    AppShell,
    AppShellHeader,
    AppShellMain,
    Button,
    Image,
    PasswordInput,
    Stack,
    TextInput,
    Title
} from "@mantine/core";
import {Header} from "@/components/header";
import NextImage from "next/image";
import {Login} from "./api";
import {useForm} from '@mantine/form';
import React from "react";
import {useRouter} from 'next/navigation';
import {useMutation} from "@tanstack/react-query";
import axios from "axios";


type Props = {
    params: {
        redirectTo: string
    }
}

type Credentials = {
    username: string,
    password: string
}

const Page = (props: Props) => {
    const router = useRouter();

    const form = useForm({
        initialValues: {
            username: "",
            password: ""
        },
    });

    const mutation = useMutation({
        mutationFn: async (credentials: Credentials) => {
            await Login(credentials.username, credentials.password)
        },

        onSuccess: async () => {
            // FIXME: Possible vulnerability. Should check if the link is from the same resource.
            await router.push(props.params.redirectTo || "/")
        },
        onError: (error) => {
            if (axios.isAxiosError(error)) {
                if (error.response?.status === 404) {
                    form.setFieldError("username", "Неверный юзернейм или пароль")
                    return
                }
            }

            form.setFieldError("username", "Что-то пошло не так. Попробуйте позже.")
        },
    });

    const onSubmit = (event) => {
        event.preventDefault()
        mutation.mutate(form.getValues())
    }

    return (
        <AppShell header={{height: 70}}>
            <AppShellHeader>
                <Header/>
            </AppShellHeader>
            <AppShellMain>
                <form
                    onSubmit={onSubmit}
                >
                    <Stack
                        align="center"
                        justify="center"
                        w="fit-content"
                        m="auto"
                        mt="10%"
                        p="md"
                        style={{color: "var(--mantine-color-bright)"}}
                    >
                        <Image
                            component={NextImage}
                            src="/gate_logo.svg"
                            alt="Gate logo"
                            width="40"
                            height="40"
                            maw="40"
                            mah="40"
                        />
                        <Title>Войти в Gate</Title>
                        <Stack w="100%" gap="0">
                            <TextInput
                                label="Username"
                                placeholder="Username"
                                key={form.key('username')}
                                w="250"
                                {...form.getInputProps('username')}
                            />
                            <PasswordInput
                                label="Пароль"
                                placeholder="Пароль"
                                w="250"
                                key={form.key('password')}
                                {...form.getInputProps('password')}
                            />
                        </Stack>
                        <Button type="submit" loading={mutation.isPending}>Войти</Button>
                    </Stack>
                </form>
            </AppShellMain>
        </AppShell>
    );
};

export {Page as LoginPage};
